#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-5HODduuDqGo4KCgQTNJDYq
key:                  fgl-arbitrary-0.2.0.6-5HODduuDqGo4KCgQTNJDYq
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  626842b4834dc17cf6b0a17405c7b4bb
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.6.6/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/fgl-arbitrary-0.2.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl-arbitrary
hs-libraries:         HSfgl-arbitrary-0.2.0.6-5HODduuDqGo4KCgQTNJDYq
depends:
    QuickCheck-2.15.0.1-8X4L6LwHv8l1J7cVx6gbL7 base-4.18.2.1
    fgl-5.8.3.0-JiFICzQTiK22BKlObydixS

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

